@@ -20,7 +20,7 @@ class Consumer:
         redis_topic = f"eventhubs-{eventhub}-{consumer_group}"
         self.redis_cache = RedisCache(redis_hostname, redis_key, redis_topic)
 
-    def recieve(self):
+    def receive(self):
         OFFSET = Offset(self.redis_cache.get_offset())
         receiver = self.eventhubs_client.add_receiver(self.consumer_group,
                                                       "0",
