@@ -14,7 +14,7 @@ class Producer:
         self.client.run()
 
     def send(self, msg):
-        self.sender.send(EventData(str(msg)))
+        self.sender.send(EventData(msg))
 
     def stop(self):
         self.client.stop()
